@@ -26,7 +26,7 @@ import re
 import gzip
 import os.path
 import time
-from .sixext.moves import urllib_request, urllib_parse, urllib_error # TODO: Replace with urllib2 (urllib is deprecated in Python 3.0)
+from .sixext.moves import urllib_request, urllib_parse, urllib_error
 import io
 from io import BytesIO
 from .sixext.moves import http_client
@@ -563,6 +563,8 @@ def probeDevices(bus=DEFAULT_PROBE_BUS, timeout=10,
                     devid = m.group(4) or ''
 
                     log.debug(uri)
+                    if("scanjet" in  mdl.lower()):
+                        continue # Do not include HP Scanjets
 
                     try:
                         back_end, is_hp, bb, model, serial, dev_file, host, zc, port = \
@@ -957,6 +959,7 @@ AGENT_healths = {AGENT_HEALTH_OK           : 'ok',
                   AGENT_HEALTH_OVERTEMP     : 'overtemp', # battery
                   AGENT_HEALTH_CHARGING     : 'charging', # battery
                   AGENT_HEALTH_DISCHARGING  : 'discharging', # battery
+                  AGENT_HEALTH_UNKNOWN      : 'unknown',
                 }
 
 
